const webpack = require('webpack');
const merge = require('webpack-merge');
const path = require('path');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');

var config = {
    entry: './src/Clock.vue',
    output: {
        path: path.resolve(__dirname + '/dist/'),
    },
    module: {
        rules: [
            {
                test: /\.js$/,
                loader: 'babel-loader',
                include: __dirname,
                exclude: /node_modules/
            },
            {
                test: /\.vue$/,
                loader: 'vue-loader'
            },
            {
                test: /\.css$/,
                loader: 'style!less!css'
            }
        ],

    },
    externals: {
        moment: 'moment'
    },
    plugins: [
        // new webpack.optimize.UglifyJsPlugin( {
        //     minimize : true,
        //     sourceMap : false,
        //     mangle: true,
        //     compress: {
        //         warnings: false
        //     }
        // } )
    ],
    optimization: {
        minimizer: [
            new UglifyJsPlugin({
                cache: true,
                parallel: true,
                uglifyOptions: {
                    compress: false,
                    ecma: 6,
                    mangle: true
                },
                sourceMap: true
            })
        ]
    }
};


module.exports = [
    merge(config, {
        entry: path.resolve(__dirname + '/src/Clock.vue'),
        output: {
            filename: 'vue-clock.js',
            // path: path.resolve(__dirname,'/dist/'),
            libraryTarget: 'umd',
            library: 'vue-clock',
            umdNamedDefine: true
        },
    }),
    merge(config, {
        entry: path.resolve(__dirname + '/src/plugin.js'),
        output: {
            filename: 'vue-clock.min.js',
            libraryTarget: 'window',
            library: 'VueClock',
        }
    }),

];
